Method: Hanami::Utils::Files.mkdir_p
- Defined in:
- lib/hanami/utils/files.rb
.mkdir_p(path) ⇒ Object
Creates a directory for the given path. It assumes that all the tokens, but the last, in path are meant to be a directory, whereas the last is meant to be a file. All the intermediate directories are created.
94 95 96 |
# File 'lib/hanami/utils/files.rb', line 94 def self.mkdir_p(path) Pathname.new(path).dirname.mkpath end |